@@ -4,13 +4,14 @@
 DailymotionUserGroupListModel::DailymotionUserGroupListModel(QObject *parent) :
     QAbstractListModel(parent)
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[DescriptionRole] = "description";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
 
     if (!Dailymotion::instance()->groupsLoaded()) {
         Dailymotion::instance()->getGroups();
@@ -20,6 +21,12 @@ DailymotionUserGroupListModel::DailymotionUserGroupListModel(QObject *parent) :
     this->connect(Dailymotion::instance(), SIGNAL(groupRemovedFromCache(int)), this, SLOT(onGroupRemoved(int)));
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> DailymotionUserGroupListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void DailymotionUserGroupListModel::onGroupAdded(int row) {
     this->beginInsertRows(QModelIndex(), row, row);
     this->endInsertRows();
