@@ -8,7 +8,7 @@
 #endif
 #endif
 
-Notifications* notificationsInstance = 0;
+Notifications* Notifications::self = 0;
 
 Notifications::Notifications(QObject *parent) :
     QObject(parent)
@@ -16,13 +16,13 @@ Notifications::Notifications(QObject *parent) :
     ,m_progressDialog(0)
   #endif
 {
-    if (!notificationsInstance) {
-        notificationsInstance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 Notifications* Notifications::instance() {
-    return notificationsInstance;
+    return !self ? new Notifications : self;
 }
 
 #ifdef Q_WS_MAEMO_5
@@ -102,6 +102,10 @@ void Notifications::showProgressDialog(const QString &message, int numberOfOpera
         this->connect(m_progressDialog, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
     }
 #else
+    if (this->sender()) {
+        this->connect(this, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
+    }
+
     emit busy(message, numberOfOperations);
 #endif
 }
@@ -116,8 +120,8 @@ void Notifications::updateProgressDialog(int progress) {
 #endif
 }
 
-#ifndef QML_USER_INTERFACE
 void Notifications::cancelProgressDialog() {
+#ifndef QML_USER_INTERFACE
     if (m_progressDialog) {
         m_progressDialog->reset();
 
@@ -125,5 +129,12 @@ void Notifications::cancelProgressDialog() {
             this->disconnect(m_progressDialog, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
         }
     }
-}
+#else
+    if (this->sender()) {
+        this->disconnect(this, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
+    }
+    else {
+        emit canceled();
+    }
 #endif
+}
