@@ -3,7 +3,6 @@
 
 #include <QObject>
 
-class CookieJar;
 class Settings;
 class Database;
 class VideoLauncher;
@@ -34,15 +33,18 @@ class Session : public QObject
 public:
     explicit Session(QObject *parent = 0);
     ~Session();
+
     inline QNetworkAccessManager* networkAccessManager() const { return m_nam; }
+
     static Session* instance();
 
 private slots:
     void onMediaPlayerChanged(const QString &player);
     
 private:
+    static Session *self;
+
     QNetworkAccessManager *m_nam;
-    CookieJar *m_jar;
     Settings *m_settings;
     Database *m_database;
     VideoLauncher *m_launcher;
