@@ -5,17 +5,21 @@
 #include "utils.h"
 #include <QTimer>
 #include <QCoreApplication>
-#include <QDebug>
 
 TransferManager* TransferManager::self = 0;
 
 TransferManager::TransferManager(QObject *parent) :
-    QObject(parent)
+    QObject(parent),
+    m_queueTimer(new QTimer(this))
 {
     if (!self) {
         self = this;
     }
 
+    m_queueTimer->setSingleShot(true);
+    m_queueTimer->setInterval(1000);
+
+    this->connect(m_queueTimer, SIGNAL(timeout()), this, SLOT(startNextTransfers()));
     this->connect(Settings::instance(), SIGNAL(maximumConcurrentTransfersChanged(int,int)), this, SLOT(onMaximumConcurrentTransfersChanged(int,int)));
     this->connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(storeTransfers()));
 }
@@ -26,11 +30,6 @@ TransferManager* TransferManager::instance() {
     return !self ? new TransferManager : self;
 }
 
-void TransferManager::timerEvent(QTimerEvent *event) {
-    this->killTimer(event->timerId());
-    this->startNextTransfers();
-}
-
 QSharedPointer<TransferItem> TransferManager::get(int i) const {
     if ((i >= 0) && (i < m_transfers.size())) {
         return m_transfers.at(i);
@@ -290,7 +289,7 @@ void TransferManager::onTransferStatusChanged(Transfers::Status status) {
     }
 
     if (m_activeTransfers.size() < Settings::instance()->maximumConcurrentTransfers()) {
-        this->startTimer(1000);
+        m_queueTimer->start();
     }
 }
 
@@ -301,19 +300,22 @@ void TransferManager::onMaximumConcurrentTransfersChanged(int oldMaximum, int ne
         }
     }
     else if (newMaximum < oldMaximum) {
-        if (newMaximum < m_activeTransfers.size()) {
-            int priority = Transfers::LowPriority;
+        int active = m_activeTransfers.size();
+        int priority = Transfers::LowPriority;
 
-            while (priority >= Transfers::HighPriority) {
-                for (int i = 0; i < m_activeTransfers.size(); i++) {
-                    if (m_activeTransfers.at(i).data()->priority() == priority) {
-                        m_activeTransfers.at(i).data()->pause();
-                        return;
-                    }
+        while ((newMaximum < active) && (priority >= Transfers::HighPriority)) {
+            int i = m_transfers.size() - 1;
+
+            while ((i >= 0) && (newMaximum < active)) {
+                if ((m_transfers.at(i).data()->status() >= Transfers::Connecting) && (m_transfers.at(i).data()->priority() == priority)) {
+                    m_transfers.at(i).data()->pause();
+                    active--;
                 }
 
-                priority--;
+                i--;
             }
+
+            priority--;
         }
     }
 }
