@@ -50,8 +50,6 @@ public slots:
     void restoreStoredTransfers();
 
 private:
-    void timerEvent(QTimerEvent *event);
-
     void getNextTransfers();
 
     void removeTransfer(TransferItem *transfer);
@@ -72,6 +70,8 @@ signals:
 private:
     static TransferManager *self;
 
+    QTimer *m_queueTimer;
+
     QList< QSharedPointer<TransferItem> > m_transfers;
     QList< QSharedPointer<TransferItem> > m_activeTransfers;
 };
