@@ -231,19 +231,28 @@ void UrlGrabber::addYouTubeDecryptionFunctionToCache() {
     }
 
     QString response(reply->readAll());
-    QString funcName = response.section("signature=", 1, 1).section('(', 0, 0);
-    QString var = response.section("function " + funcName, 0, 0).section(";var", -1);
-    QString funcBody = QString("function %2%3").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
-    QString js = QString("var%1 %2").arg(var).arg(funcBody);
-    qDebug() << "Found decryption function:" << js;
-    youtubeDecryptionEngine->evaluate(js);
+    QRegExp re("\\.sig\\|\\|\\w+(?=\\()");
 
-    QScriptValue global = youtubeDecryptionEngine->globalObject();
-    QScriptValue decryptionFunction = global.property(funcName);
+    if (re.indexIn(response) != -1) {
+        QString funcName = re.cap().section("||", -1);
+        QString var = response.section("function " + funcName, 0, 0).section(";var", -1);
+        QString funcBody = QString("function %2%3").arg(funcName).arg(response.section("function " + funcName, 1, 1).section(";function", 0, 0));
+        QString js = QString("var%1 %2").arg(var).arg(funcBody);
+        qDebug() << "Found decryption function:" << js;
+        youtubeDecryptionEngine->evaluate(js);
 
-    if (decryptionFunction.isFunction()) {
-        youtubeDecryptionCache[reply->request().url()] = decryptionFunction;
-        emit youtubeDecryptionFunctionReady(decryptionFunction);
+        QScriptValue global = youtubeDecryptionEngine->globalObject();
+        QScriptValue decryptionFunction = global.property(funcName);
+
+        if (decryptionFunction.isFunction()) {
+            youtubeDecryptionCache[reply->request().url()] = decryptionFunction;
+            emit youtubeDecryptionFunctionReady(decryptionFunction);
+        }
+        else {
+            this->setBusy(false);
+            emit error(tr("Unable to decrypt video signature"));
+            this->disconnect(this, SIGNAL(youtubeDecryptionFunctionReady(QScriptValue)), 0, 0);
+        }
     }
     else {
         this->setBusy(false);
@@ -420,7 +429,7 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
 }
 
 void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
-    QUrl url("https://www.youtube.com/watch");
+    QUrl url("http://www.youtube.com/watch");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("v", id);
@@ -435,6 +444,7 @@ void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     url.addQueryItem("has_verified", "1");
 #endif
     QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:28.0) Gecko/20100101  Firefox/28.0");
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
