@@ -43,6 +43,7 @@ VideoItem::VideoItem(VideoItem *video, QObject *parent) :
     m_viewCount(video->viewCount()),
     m_thumbUrl(video->thumbnailUrl()),
     m_largeThumbUrl(video->largeThumbnailUrl()),
+    m_subtitlesUrl(video->subtitlesUrl()),
     m_liked(video->liked()),
     m_disliked(video->disliked()),
     m_favourite(video->favourite()),
@@ -94,6 +95,7 @@ void VideoItem::loadVideo(VideoItem *video) {
     this->setViewCount(video->viewCount());
     this->setThumbnailUrl(video->thumbnailUrl());
     this->setLargeThumbnailUrl(video->largeThumbnailUrl());
+    this->setSubtitlesUrl(video->subtitlesUrl());
     this->setLiked(video->liked());
     this->setDisliked(video->disliked());
     this->setFavourite(video->favourite());
