@@ -15,6 +15,9 @@ public:
         
 public slots:
     static void launchVideo(const QUrl &url);
+
+private:
+    static VideoLauncher *self;
 };
 
 #endif // VIDEOLAUNCHER_H
