@@ -7,13 +7,14 @@
 VimeoAccountsListModel::VimeoAccountsListModel(QObject *parent) :
     QSqlTableModel(parent, QSqlDatabase::database())
 {
-    QHash<int, QByteArray> roles;
-    roles[DisplayNameRole] = "displayName";
-    roles[UsernameRole] = "username";
-    roles[AccessTokenRole] = "accessToken";
-    roles[TokenSecretRole] = "tokenSecret";
-    roles[ActiveRole] = "active";
-    this->setRoleNames(roles);
+    m_roleNames[DisplayNameRole] = "displayName";
+    m_roleNames[UsernameRole] = "username";
+    m_roleNames[AccessTokenRole] = "accessToken";
+    m_roleNames[TokenSecretRole] = "tokenSecret";
+    m_roleNames[ActiveRole] = "active";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
     this->setTable("vimeoAccounts");
     this->setEditStrategy(QSqlTableModel::OnManualSubmit);
     this->select();
@@ -30,6 +31,12 @@ VimeoAccountsListModel::~VimeoAccountsListModel() {
     this->clear();
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> VimeoAccountsListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void VimeoAccountsListModel::setActiveAccount(int row) {
     this->database().open();
     QSqlField nameField("name", QVariant::String);
