@@ -1,6 +1,6 @@
 #include "youtube.h"
 #include "json.h"
-#include "utils.h"
+#include "definitions.h"
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QNetworkReply>
@@ -22,7 +22,7 @@
 
 using namespace QtJson;
 
-YouTube* youtubeInstance = 0;
+YouTube* YouTube::self = 0;
 
 const QByteArray CLIENT_ID("446197852855.apps.googleusercontent.com");
 const QByteArray CLIENT_SECRET("YzuBGnTyRdz9cK5J3Pg5Xlte");
@@ -40,8 +40,8 @@ YouTube::YouTube(QObject *parent) :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!youtubeInstance) {
-        youtubeInstance = this;
+    if (!self) {
+        self = this;
     }
 
     m_queryOrders[Queries::Relevance] = "relevance";
@@ -64,7 +64,7 @@ YouTube::~YouTube() {
 }
 
 YouTube* YouTube::instance() {
-    return youtubeInstance;
+    return !self ? new YouTube : self;
 }
 
 void YouTube::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -121,7 +121,7 @@ QNetworkReply* YouTube::createReply(QUrl feed, int offset) {
     qDebug() << feed;
 
     QNetworkRequest request(feed);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("X-Gdata-Key", "key=" + DEVELOPER_KEY);
 
     return this->networkAccessManager()->get(request);
@@ -213,7 +213,7 @@ QNetworkReply* YouTube::createSearchReply(int queryType, const QString &query, i
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
 
     return this->networkAccessManager()->get(request);
 }
@@ -237,7 +237,7 @@ QNetworkReply* YouTube::createUploadReply(const QVariantMap &metadata) {
     }
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Host", "uploads.gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml; charset=UTF-8");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
@@ -287,7 +287,7 @@ void YouTube::signIn(const QString &displayName, const QString &code) {
                     "&redirect_uri=urn:ietf:wg:oauth:2.0:oob&grant_type=authorization_code");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedIn()));
@@ -333,7 +333,7 @@ void YouTube::signInFromDevice(const QString &displayName) {
     QUrl url("https://accounts.google.com/o/oauth2/device/code");
     QByteArray body("scope=https://gdata.youtube.com&client_id=" + CLIENT_ID);
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkDeviceSignInInfo()));
@@ -395,7 +395,7 @@ void YouTube::pollServerForDeviceToken() {
                     "&code=" + m_login.deviceCode.toUtf8());
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkDeviceToken()));
@@ -499,7 +499,7 @@ void YouTube::refreshAccessToken() {
                     "&grant_type=refresh_token");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QNetworkReply *reply = this->networkAccessManager()->post(request, body);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkTokenRefresh()));
@@ -586,7 +586,7 @@ void YouTube::checkUsernameAvailability(QString username) {
     url.addQueryItem("hint", username);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("X-Gdata-Key", "key=" + DEVELOPER_KEY);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkSuggestedUsernames()));
@@ -660,7 +660,7 @@ void YouTube::postRequest(const QUrl &url, const QByteArray &xml) {
     qDebug() << url;
     qDebug() << xml;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Host", "gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
@@ -676,7 +676,7 @@ void YouTube::putRequest(const QUrl &url, const QByteArray &xml) {
     qDebug() << url;
     qDebug() << xml;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Host", "gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
@@ -691,7 +691,7 @@ void YouTube::putRequest(const QUrl &url, const QByteArray &xml) {
 void YouTube::deleteRequest(const QUrl &url) {
     qDebug() << url;
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Host", "gdata.youtube.com");
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
     request.setRawHeader("Authorization", "Bearer " + this->accessToken().toUtf8());
@@ -764,7 +764,7 @@ void YouTube::getPlaylists(int offset) {
     url.addQueryItem("access_token", this->accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addPlaylists()));
 }
@@ -878,7 +878,7 @@ void YouTube::getSubscriptions(int offset) {
     url.addQueryItem("access_token", this->accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addSubscriptions()));
 }
@@ -988,7 +988,7 @@ void YouTube::getFullVideo(QString id) {
     url.addQueryItem("fields", YOUTUBE_SINGLE_VIDEO_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullVideo()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -1049,7 +1049,7 @@ void YouTube::getVideoMetadata(const QString &id) {
     url.addQueryItem("access_token", this->accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkVideoMetadata()));
 }
@@ -1127,7 +1127,7 @@ void YouTube::getFullComment(const QString &videoId, const QString &commentId) {
     url.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkFullComment()));
 }
@@ -1170,7 +1170,7 @@ void YouTube::getCurrentUserProfile() {
     url.addQueryItem("access_token", this->accessToken());
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCurrentUserProfile()));
 }
@@ -1229,7 +1229,7 @@ void YouTube::getUserProfile(const QString &id) {
     url.addQueryItem("fields", YOUTUBE_USER_PROFILE_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkUserProfile()));
 }
@@ -1740,7 +1740,7 @@ void YouTube::getPlaylistForCache(const QString &id) {
 #endif
     QNetworkRequest request(url);
     request.setRawHeader("X-Gdata-Key", "key=" + DEVELOPER_KEY);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkCachePlaylist()));
 }
@@ -1997,7 +1997,7 @@ void YouTube::getAddedComment(const QString &videoId, const QString &commentId)
     url.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkAddedComment()));
 }
@@ -2076,7 +2076,7 @@ void YouTube::getVideosFromIds(QStringList ids) {
     xml.append("</feed>");
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/atom+xml");
     request.setHeader(QNetworkRequest::ContentLengthHeader, xml.length());
     QNetworkReply *reply = this->networkAccessManager()->post(request, xml);
