@@ -19,7 +19,7 @@ private slots:
     void onCategoryChosen(const QModelIndex &index);
 
 signals:
-    void categoryChosen(Services::VideoService, const QString &title, const QString &feed);
+    void categoryChosen(Services::VideoService, const QString &title, const QUrl &feed);
 
 private:
     DailymotionCategoryModel *m_model;
