@@ -33,13 +33,6 @@ public slots:
     void playlistSearch(const QString &query, Services::VideoService service, Queries::QueryOrder order = Queries::Relevance);
     void groupSearch(const QString &query, Services::VideoService service, Queries::QueryOrder order = Queries::Relevance);
     void userSearch(const QString &query, Services::VideoService service);
-    void showYouTubeVideo(QSharedPointer<VideoItem> video);
-    void showDailymotionVideo(QSharedPointer<VideoItem> video);
-    void showVimeoVideo(QSharedPointer<VideoItem> video);
-    void display(const QStringList &urls);
-    void display(const QString &url);
-    void play(const QStringList &urls);
-    void play(const QString &url);
 
 private slots:
     void showSettingsDialog();
