@@ -59,17 +59,28 @@ void TransferListWindow::showContextMenu(const QPoint &pos) {
         return;
     }
 
-    Transfers::Status status = static_cast<Transfers::Status>(index.data(TransferItem::StatusRole).toInt());
-
-    switch (status) {
+    switch (index.data(TransferItem::StatusRole).toInt()) {
     case Transfers::Paused:
+        m_pauseResumeAction->setEnabled(true);
         m_pauseResumeAction->setText(tr("Start"));
         break;
     case Transfers::Failed:
+        m_pauseResumeAction->setEnabled(true);
         m_pauseResumeAction->setText(tr("Start"));
         break;
     default:
         m_pauseResumeAction->setText(tr("Pause"));
+
+        switch (index.data(TransferItem::TransferTypeRole).toInt()) {
+        case Transfers::Upload:
+            m_pauseResumeAction->setEnabled(false);
+            break;
+        default:
+            m_pauseResumeAction->setEnabled(true);
+            break;
+        }
+
+        break;
     }
 
     m_contextMenu->popup(pos, m_priorityAction);
