@@ -17,7 +17,7 @@ class VimeoChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit VimeoChannelWindow(Session *session, const QString &userId, QWidget *parent);
+    explicit VimeoChannelWindow(const QString &userId, QWidget *parent);
 
 private:
     void clearMenuActions();
