@@ -3,7 +3,6 @@
 
 #include "stackedwindow.h"
 
-class Session;
 class VimeoProfileTab;
 class VimeoVideoListTab;
 class VimeoUserAlbumListTab;
@@ -18,7 +17,7 @@ class VimeoMyChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit VimeoMyChannelWindow(Session *session, QWidget *parent);
+    explicit VimeoMyChannelWindow(QWidget *parent);
 
 private:
     void clearMenuActions();
