@@ -2,10 +2,12 @@
 #include "vimeovideolistwindow.h"
 #include "../base/notifications.h"
 #include "../base/vimeo.h"
+#include "../base/utils.h"
 #include "windowstack.h"
 #include "../base/thumbnailcache.h"
 #include "separatorlabel.h"
 #include "avatarlabel.h"
+#include "resourceloader.h"
 #include <QLabel>
 #include <QPushButton>
 #include <QScrollArea>
@@ -47,6 +49,7 @@ VimeoProfileTab::VimeoProfileTab(const QString &userId, QWidget *parent) :
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_websiteLabel->setOpenExternalLinks(true);
     m_descriptionLabel->setWordWrap(true);
     m_scrollArea->hide();
     m_noProfileLabel->hide();
@@ -56,7 +59,7 @@ VimeoProfileTab::VimeoProfileTab(const QString &userId, QWidget *parent) :
 
     this->connect(Vimeo::instance(), SIGNAL(gotUser(QSharedPointer<UserItem>)), this, SLOT(setUser(QSharedPointer<UserItem>)));
     this->connect(Vimeo::instance(), SIGNAL(error(QString)), this, SLOT(onProfileError()));
-    this->connect(m_websiteLabel, SIGNAL(linkActivated(QString)), this, SLOT(showUserWebsite()));
+    this->connect(m_descriptionLabel, SIGNAL(linkActivated(QString)), this, SLOT(parseActivatedLink(QString)));
     this->connect(m_subscriptionButton, SIGNAL(clicked()), this, SLOT(toggleSubscription()));
 
     if ((userId == "me") || (userId == Vimeo::instance()->username())) {
@@ -88,7 +91,7 @@ void VimeoProfileTab::setUser(QSharedPointer<UserItem> user) {
     m_videosLabel->setText(!m_user.data()->videoCount() ? tr("No videos") : QString ("%1 %2").arg(m_user.data()->videoCount()).arg(tr("videos")));
     m_locationLabel->setText(QString("%1: %2").arg(tr("Location")).arg(m_user.data()->location().isEmpty() ? tr("Unknown") : m_user.data()->location()));
     m_websiteLabel->setText(m_user.data()->websiteUrl().isEmpty() ? tr("No website") : QString("%1: <a href='%2'>%2</a>").arg("Website").arg(m_user.data()->websiteUrl().toString()));
-    m_descriptionLabel->setText(m_user.data()->description().isEmpty() ? tr("No description") : m_user.data()->description());
+    m_descriptionLabel->setText(m_user.data()->description().isEmpty() ? tr("No description") : Utils::toRichText(m_user.data()->description()));
     m_subscriptionButton->setText(m_user.data()->subscribed() ? tr("Unsubscribe") : tr("Subscribe"));
 
     m_scrollArea->show();
@@ -130,13 +133,15 @@ void VimeoProfileTab::onSubscribedChanged(bool subscribed) {
     m_subscriptionButton->setText(subscribed ? tr("Unsubscribe") : tr("Subscribe"));
 }
 
-void VimeoProfileTab::showUserWebsite() {
-    QDesktopServices::openUrl(m_user.data()->websiteUrl());
-}
-
 void VimeoProfileTab::showWatchLaterAlbum() {
     VimeoVideoListWindow *window = new VimeoVideoListWindow(WindowStack::instance()->currentWindow());
     window->setWindowTitle(tr("Watch later"));
     window->setVideoFeed(VIMEO_WATCH_LATER_FEED);
     window->show();
 }
+
+void VimeoProfileTab::parseActivatedLink(const QString &link) {
+    if (!ResourceLoader::instance()->display(link, false)) {
+        QDesktopServices::openUrl(link);
+    }
+}
