@@ -3,7 +3,6 @@
 
 #include "abstracttab.h"
 
-class Session;
 class VimeoSubscriptionListModel;
 class ListView;
 class QMenu;
@@ -16,7 +15,7 @@ class VimeoSubscriptionsTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit VimeoSubscriptionsTab(Session *session, QWidget *parent = 0);
+    explicit VimeoSubscriptionsTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -32,7 +31,6 @@ private slots:
     void showSubscriptionVideos();
 
 private:
-    Session *m_session;
     VimeoSubscriptionListModel *m_model;
     ListView *m_listView;
     QMenu *m_contextMenu;
