@@ -16,7 +16,7 @@ class YouTubeChannelWindow : public StackedWindow
     Q_OBJECT
 
 public:
-    explicit YouTubeChannelWindow(Session *session, const QString &userId, QWidget *parent);
+    explicit YouTubeChannelWindow(const QString &userId, QWidget *parent);
     
 private:
     void clearMenuActions();
